@@ -20,12 +20,4 @@ import revsymg.graphs
 # ============================================================================ #
 #                                      LIB                                     #
 # ============================================================================ #
-import revsymg.lib
-# ============================================================================ #
-#                              READS'S IDENTIFIERS                             #
-# ============================================================================ #
-import revsymg.hash_ids
-# ============================================================================ #
-#                                  UTILITARIES                                 #
-# ============================================================================ #
-import revsymg.utils
+import revsymg.index_lib
