@@ -8,7 +8,7 @@ from collections.abc import Iterable
 from typing import Any, Iterator
 
 from revsymg.exceptions import WrongAttributeType, _NoAttribute, _NoKey
-from revsymg.lib.index_lib import IndexT
+from revsymg.index_lib import IndexT
 
 
 # ============================================================================ #
