@@ -17,7 +17,7 @@ from revsymg.exceptions import (
 )
 from revsymg.graphs._adjancy_table import _AdjsT
 from revsymg.graphs.attributes import AttributesContainer
-from revsymg.lib.index_lib import (
+from revsymg.index_lib import (
     FORWARD_INT,
     FWDOR_REVOR,
     IND,
